<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en_US">
<context>
    <name>AboutDialog</name>
    <message>
        <source>cuteTube-QML - 0.6.1</source>
        <translation type="obsolete">cuteTube-QML - 0.6.1 - PL</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.3</source>
        <translation type="obsolete">cuteTube-QML - 0.6.3 - PL</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.5</source>
        <translation type="obsolete">cuteTube-QML - 0.6.5 - PL</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.0</source>
        <translation type="obsolete">cuteTube-QML - 0.7.0 - PL</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.1</source>
        <translation type="obsolete">cuteTube-QML - 0.7.1 - PL</translation>
    </message>
    <message>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="obsolete">Multifunkcjonalny klient Youtube dla Noki N900. To jest eksperymentalne wydanie wykorzystującye QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.3</source>
        <translation type="obsolete">cuteTube-QML - 0.7.3 - PL</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.5</source>
        <translation type="obsolete">cuteTube-QML - 0.7.5 - PL</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.7.6</source>
        <translation type="unfinished">cuteTube-QML - 0.7.6 - PL</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Nowe Konto</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Edytuj Konto</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Błąd bazy danych. Nie można zapisać konta</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation>Urzytkownik</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="95"/>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="108"/>
        <source>Default?</source>
        <translation>Domyślny?</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>Konta YouTube</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Dodaj komentarz</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Udostępnij przez</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Wiadomość</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Dodaj do listy odtwarzania</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Zaznacz wiele</translation>
    </message>
    <message>
        <source>Delete from archive</source>
        <translation type="obsolete">Usuń z archiwum</translation>
    </message>
    <message>
        <source>Delete from device</source>
        <translation type="obsolete">Usuń z urządzenia</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="49"/>
        <source>Deleted from archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="52"/>
        <location filename="../ArchiveListView.qml" line="69"/>
        <source>Unable to delete from archive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="50"/>
        <source>Loading...</source>
        <translation>Ładowanie...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Zmień bierzącego urzytkownika</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source>By </source>
        <translation>Przez </translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <location filename="../CommentsDelegate.qml" line="23"/>
        <source> on </source>
        <translation> na </translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Zatrzymaj!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>cuteTube jest w trakcie pobierania. Czy naprawdę chcesz wyjść z programu?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>Dutch</source>
        <translation type="obsolete">Holenderski</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Polski</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="222"/>
        <source>Video deleted from device</source>
        <translation>Plik wideo usunięty z urządzenia</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="225"/>
        <source>Unable to delete video</source>
        <translation>Nie można usunąć pliku wideo</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="229"/>
        <source>Video not found</source>
        <translation>Plik wideo nie znaleziony</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="284"/>
        <source>Copied to clipboard</source>
        <translation>Skopiowany do schowka</translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Wstrzymany</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">W kolejce</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Nieudany</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Pobieranie</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Nieudany</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Pobieranie</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Wstrzymany</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Wybierz plik wideo</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Ustawienia</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation type="obsolete">Konta</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">O programie</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="119"/>
        <source>My Channel</source>
        <translation>Mój kanał</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="143"/>
        <source>Most Recent</source>
        <translation>Ostatnio dodane</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="167"/>
        <source>Most Viewed</source>
        <translation>Najczęściej oglądane</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="191"/>
        <source>Archive</source>
        <translation>Archiwum</translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <source>Menu</source>
        <translation type="obsolete">Menu</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="obsolete">Wstecz</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Wyjście</translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="133"/>
        <source>Sort</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <source>Upload video</source>
        <translation type="obsolete">Wysłane wideo</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="81"/>
        <source>My Uploads</source>
        <translation>Moje wysłane pliki</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="87"/>
        <source>Uploads</source>
        <translation>Wysyłane</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="105"/>
        <source>My Favourites</source>
        <translation>Moje Ulubione</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="111"/>
        <source>Favourites</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="135"/>
        <source>Playlists</source>
        <translation>Listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="159"/>
        <source>Subscriptions</source>
        <translation>Subskrypcje</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="174"/>
        <source>Signed in as:</source>
        <translation>Zaloguj mnie jako:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Nowa lista odtwarzania</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Opis (opcjonalnie)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Prywatny?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Cześć!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>Nazywam się Cutey. Mój kumpel Spinacz mówi mi, że to jest Twoje pierwsze uruchomienie cuteTube. Czy chcesz dodać konto YouTube?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>Odejdź sobie</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="52"/>
        <source>No active downloads</source>
        <translation>Brak aktywnych pobrań </translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="147"/>
        <source>Downloads</source>
        <translation>Pobrania</translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Zezwolenie dla</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Błąd otrzymywania pozwolenia Facebooka</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Wprowadź kod pin</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="31"/>
        <source> videos</source>
        <translation> pliki wideo</translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Zaznacz wiele</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Pobierz wideo</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Pobierz dźwięk</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Dodoaj do ulubionych</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Dodaj do listy odtwarzania</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Skopiuj do schowka</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="69"/>
        <source>Video(s) deleted from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="90"/>
        <source>No videos found</source>
        <translation>Nie znaleziono plików wideo</translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="58"/>
        <source>New playlist created</source>
        <translation>Utworzono nową listę odtwarania</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Nowa lista odtwarzania</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="106"/>
        <source>No playlists found</source>
        <translation>Brak list odtwarzania</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="30"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="44"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="51"/>
        <source>Port (e.g. 8080)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Relevance</source>
        <translation>Związek</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Rating</source>
        <translation>Ocena</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="15"/>
        <source>Views</source>
        <translation>Wyświetlenia</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="182"/>
        <source>Order by:</source>
        <translation>Stortuj po:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="195"/>
        <source>Your saved searches have been cleared</source>
        <translation>Twoje zapisane wyszukiwania zostały wyczyszczone</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="198"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Błąd bazy danych. Nie można wyczyścić wyszukiwań</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="245"/>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="311"/>
        <source>Playback quality</source>
        <translation>Jakość odtwarzania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="320"/>
        <source>Download quality</source>
        <translation>Jakość pobierania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="286"/>
        <source>Start downloads</source>
        <translation>Uruchomienie pobierania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="354"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="379"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="387"/>
        <source>Download location</source>
        <translation>Miejsce pobierania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="396"/>
        <source>Screen orientation</source>
        <translation>Orientacja ekranu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="302"/>
        <source>Media player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="171"/>
        <location filename="../SettingsDialog.qml" line="371"/>
        <location filename="../SettingsDialog.qml" line="373"/>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="37"/>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>High quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>360p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>480p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>720p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Most recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Most viewed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Archive</source>
        <translation type="unfinished">Archiwum</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Latest subscription videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>My uploads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>My favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="123"/>
        <location filename="../SettingsDialog.qml" line="174"/>
        <source>Network Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="147"/>
        <location filename="../SettingsDialog.qml" line="313"/>
        <source>Playback Quality</source>
        <translation>Jakość odtwarzania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="150"/>
        <location filename="../SettingsDialog.qml" line="322"/>
        <source>Download Quality</source>
        <translation>Jakość pobierania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="153"/>
        <location filename="../SettingsDialog.qml" line="288"/>
        <source>Start Downloads</source>
        <translation>Uruchom pobieranie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="162"/>
        <location filename="../SettingsDialog.qml" line="398"/>
        <source>Screen Orientation</source>
        <translation>Orientacja ekranu</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="165"/>
        <location filename="../SettingsDialog.qml" line="304"/>
        <source>Media Player</source>
        <translation>Odtwarzacz</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="412"/>
        <source>Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="420"/>
        <source>Feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="429"/>
        <source>Feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="438"/>
        <source>Feed three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="447"/>
        <source>Feed four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="37"/>
        <location filename="../SettingsDialog.qml" line="38"/>
        <source>Mobile</source>
        <translation>Mobilny</translation>
    </message>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Wysoka jakość</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Automatically</source>
        <translation>Automatycznie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="39"/>
        <source>Manually</source>
        <translation>Ręcznie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <source>On</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <source>Off</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Automatic</source>
        <translation>Automatyczna</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Landscape</source>
        <translation>Pozioma</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Portrait</source>
        <translation>Pionowa</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Light</source>
        <translation>Jasny</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Dark</source>
        <translation>Ciemny</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>English</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>German</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Finnish</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Italian</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Dutch</source>
        <translation>Holenderski</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Polish</source>
        <translation>Polski</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">W Kolejce</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Wstrzymany</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="108"/>
        <source>Your settings have been saved</source>
        <translation>Twoje ustawienia zostały zapisane</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="113"/>
        <location filename="../SettingsDialog.qml" line="156"/>
        <source>Download Path</source>
        <translation>Ścieżka pobierania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="115"/>
        <source>Download Location</source>
        <translation>Miejsce Pobierania</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="159"/>
        <location filename="../SettingsDialog.qml" line="338"/>
        <source>Safe Search</source>
        <translation>Bezpieczne wyszukiwanie</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="168"/>
        <location filename="../SettingsDialog.qml" line="362"/>
        <location filename="../SettingsDialog.qml" line="364"/>
        <source>Theme</source>
        <translation>Skórka</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="177"/>
        <location filename="../SettingsDialog.qml" line="422"/>
        <source>Widget Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="180"/>
        <location filename="../SettingsDialog.qml" line="431"/>
        <source>Widget Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="183"/>
        <location filename="../SettingsDialog.qml" line="440"/>
        <source>Widget Feed Three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="186"/>
        <location filename="../SettingsDialog.qml" line="449"/>
        <source>Widget Feed Four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="269"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="277"/>
        <source>Network proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="294"/>
        <source>Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="328"/>
        <source>YouTube searches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="336"/>
        <source>Safe search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="278"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="347"/>
        <source>Clear saved searches</source>
        <translation>Wyczyść zapisane wyszukiwania</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Błąd - Serwer odpowiedział:</translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="36"/>
        <source>Latest Subscriptions Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="45"/>
        <source>You have unsubscribed to this channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have unsubscribed to &apos;</source>
        <translation type="obsolete">Anulowałeś subskrypcje &apos;</translation>
    </message>
    <message>
        <source>Latest Subscription Videos</source>
        <translation type="obsolete">Ostanie wideo subskrypcje</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="104"/>
        <source>No subscriptions found</source>
        <translation>Brak subskrpcji</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Samochody i Pojazdy </translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="8"/>
        <source>Comedy</source>
        <translation>Komedia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <source>Education</source>
        <translation>Edukacja</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="9"/>
        <location filename="../UploadDialog.qml" line="19"/>
        <source>Entertainment</source>
        <translation>Rozrywka</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Film and Animation</source>
        <translation>Filmy i animacja</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="10"/>
        <source>Gaming</source>
        <translation>Gry</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Howto &amp; Style</source>
        <translation>Jak i Styl</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>Music</source>
        <translation>Muzyka</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="11"/>
        <source>News &amp; Politics</source>
        <translation>Wiadomości i Polityka</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Non-profit i aktywizm</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="12"/>
        <source>People &amp; Blogs</source>
        <translation>Ludzie i Blogi</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Pets &amp; Animals</source>
        <translation>Zwierzęta</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <source>Science &amp; Technology</source>
        <translation>Nauka i Technologia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Sport</source>
        <translation>Sport</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="14"/>
        <source>Travel &amp; Events</source>
        <translation>Podruże i wydarzenia</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="35"/>
        <location filename="../UploadDialog.qml" line="216"/>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="114"/>
        <source>Upload Video</source>
        <translation>Umieść wideo</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="139"/>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="148"/>
        <location filename="../UploadDialog.qml" line="224"/>
        <source>None chosen</source>
        <translation>Nie wybrany</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="164"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="177"/>
        <source>Description (optional)</source>
        <translation>Opis (opcjonalnie)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="189"/>
        <source>Tags (seperated by commas)</source>
        <translation>Tagi (odzielone przecinkami)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="202"/>
        <source>Private?</source>
        <translation>Prywatny?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>Uruchomienie umieszczania</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Status umieszczania</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Trwa umieszczanie</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="127"/>
        <source>Subscribers</source>
        <translation>Subskrybenci</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="141"/>
        <source>Videos</source>
        <translation>Pliki wideo</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="129"/>
        <source>You have subscribed to &apos;</source>
        <translation>Zasubskrybowałeś się do &apos;</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="133"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>Anulowałeś subskrybcje &apos;</translation>
    </message>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Zaznacz wiele</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Pobierz wideo</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Pobierz dźwięk</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Dodaj do listy odtwarzania</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Skopiuj do schowka</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="153"/>
        <source>No videos found</source>
        <translation>Brak plików wideo</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="212"/>
        <source>Subscribers</source>
        <translation>Subskrybenci</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="226"/>
        <source>Videos</source>
        <translation>Pliki wideo</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="249"/>
        <source>Unsubscribe</source>
        <translation>Wypisz z subskrybcji</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="249"/>
        <source>Subscribe</source>
        <translation>Zapisz do subskrybcji</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Brak opisu</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="92"/>
        <source>Your comment has been added</source>
        <translation>Twój komentarz został dodany</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="95"/>
        <source>Your rating has been added</source>
        <translation>Twoja ocena została dodana</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="102"/>
        <source>Video shared on facebook</source>
        <translation>Udostępniłeś wideo na Facebooku</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Dodaj do listy odtwarzania</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Skopiuj do schowka</translation>
    </message>
    <message>
        <source>Share via facebook</source>
        <translation type="obsolete">Udostępnij prtzez Facebook</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="443"/>
        <location filename="../VideoInfoView.qml" line="467"/>
        <location filename="../VideoInfoView.qml" line="580"/>
        <source>You are not signed in to a YouTube account</source>
        <translation>Nie jesteś zalogowany do swojego konta YouTube</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="244"/>
        <source>Info</source>
        <translation>Informacja</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="283"/>
        <source>Comments</source>
        <translation>Komentarze</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="322"/>
        <source>Related</source>
        <translation>Podobne</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="413"/>
        <location filename="../VideoInfoView.qml" line="416"/>
        <source>By </source>
        <translation>Przez </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="415"/>
        <location filename="../VideoInfoView.qml" line="418"/>
        <source> on </source>
        <translation> na </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="484"/>
        <source>Views</source>
        <translation>Wyświetlenia</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="498"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="514"/>
        <source>Tags</source>
        <translation>Tagi</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="524"/>
        <source>No tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="592"/>
        <source>No comments</source>
        <translation>Brak komentarzy</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="592"/>
        <source> comments</source>
        <translation> komentarzy</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="685"/>
        <source>No related videos</source>
        <translation>Brak podobnych plików wideo</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source>By </source>
        <translation>Przez </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source> on </source>
        <translation> na </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="102"/>
        <source>Views</source>
        <translation>Wyświetlenia</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Zaznacz wiele</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Pobierz wideo</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Pobierz dźwięk</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Dodaj do ulubionych</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Dodaj do listy odtwarzania</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">Skopiuj do schowka</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="86"/>
        <source>Video(s) deleted from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="108"/>
        <source>No videos found</source>
        <translation>Brak plików wideo</translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Błąd: Nie można odebrać wideo</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="40"/>
        <source>Error obtaining access token</source>
        <translation>Błąd otrzymania tokenu</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="55"/>
        <source>Authentication failed</source>
        <translation>Błąd uwierzytelnienia</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="59"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>Jesteś zalogowany do YouTube jako &apos;</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="164"/>
        <location filename="../../../youtube.cpp" line="270"/>
        <source>Error - Server repsonse is: </source>
        <translation>Błąd - Serwer odpowiedział:</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="214"/>
        <location filename="../../../youtube.cpp" line="222"/>
        <source>Upload aborted</source>
        <translation>Wysyłanie anulowane</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="229"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Wysyłanie przerwane. Próba wznowienia...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="233"/>
        <source>Upload failed</source>
        <translation>Wysyłanie nie udane</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="239"/>
        <source>Upload is completed</source>
        <translation>Wysyłanie ukończone</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="437"/>
        <location filename="../../../youtube.cpp" line="479"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Błąd: Nie można odebrać wideo</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Ciemny</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="obsolete">Jasny</translation>
    </message>
    <message>
        <location filename="../main.qml" line="112"/>
        <source>Video(s) added to download queue</source>
        <translation>Plik(i) wideo dodane do kolejki pobierania</translation>
    </message>
    <message>
        <location filename="../main.qml" line="115"/>
        <source>Video(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="126"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Plik(i) audio dodane do kolejki pobierania</translation>
    </message>
    <message>
        <location filename="../main.qml" line="129"/>
        <source>Audio track(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video added to favourites</source>
        <translation type="obsolete">Wideo dodane do ulubionych</translation>
    </message>
    <message>
        <source>Video added to playlist</source>
        <translation type="obsolete">Wideo dodane do listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../main.qml" line="169"/>
        <source>New playlist created</source>
        <translation>Utworzono nową listę odtwarzania</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Converting</source>
        <translation>Konwersja</translation>
    </message>
    <message>
        <location filename="../main.qml" line="219"/>
        <source>Conversion of &apos;</source>
        <translation>Konwersja &apos;</translation>
    </message>
    <message>
        <location filename="../main.qml" line="160"/>
        <source>Video(s) added to favourites</source>
        <translation>Wideo(i) dodane do ulubionych</translation>
    </message>
    <message>
        <location filename="../main.qml" line="161"/>
        <source>Video(s) added to playlist</source>
        <translation>Wideo(i) dodane do listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../main.qml" line="219"/>
        <source>&apos; failed</source>
        <translation>&apos; nieudana</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation type="obsolete">Mobilny</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Queued</source>
        <translation>W Kolejce</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Paused</source>
        <translation>Wstrzymany</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <location filename="../main.qml" line="234"/>
        <source>Failed</source>
        <translation>Nieudany</translation>
    </message>
    <message>
        <location filename="../main.qml" line="417"/>
        <source>Most Recent</source>
        <translation>Ostatnio dodane</translation>
    </message>
    <message>
        <location filename="../main.qml" line="418"/>
        <source>Most Viewed</source>
        <translation>Najczęściej oglądane</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Odtwarzacz</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="152"/>
        <source>My Channel</source>
        <translation>Mój kanał</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="167"/>
        <source>Archive</source>
        <translation>Archiwum</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="206"/>
        <source>My Playlists</source>
        <translation>Moje listy odtwarzania</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="216"/>
        <source>My Subscriptions</source>
        <translation>Moje Subskrybcje</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="229"/>
        <source>Video Info</source>
        <translation>Informacja o Wideo</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="239"/>
        <source>Video Playback</source>
        <translation>Odtwarzanie Wideo</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="obsolete">Pobierania</translation>
    </message>
    <message>
        <source>date</source>
        <translation type="obsolete">data</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">wyświetlenia</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">związek</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">oceny</translation>
    </message>
    <message>
        <location filename="../scripts/mainscripts.js" line="252"/>
        <source>Search </source>
        <translation>Wyszukaj </translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Wysoka jakość</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Wstrzymany</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="obsolete">Automatycznie</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Odtwarzacz</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Data</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Ciemny</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Angielski</translation>
    </message>
</context>
</TS>
